ardt.preprocessors.filters.ButterworthFilter.ButterworthFilter
==============================================================

.. currentmodule:: ardt.preprocessors.filters.ButterworthFilter

.. autoclass:: ButterworthFilter

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ButterworthFilter.__init__
      ~ButterworthFilter.process_signal
      ~ButterworthFilter.resolve
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~ButterworthFilter.context
   
   